SqlPlaceholder

Enum SqlPlaceholder 

pub enum SqlPlaceholder {
    QuestionMark,
    NumberedQuestionMark,
    DollarNumber,
}
SQL bind-parameter placeholder syntax accepted by a driver.

This describes the SQL text users must write when sending raw SQL through RawSql. The SQL serializer uses the same value when rendering Toasty-generated SQL.

Variants



QuestionMark

Positional ? placeholders, where parameter order is the occurrence order in the SQL string.



NumberedQuestionMark

Numbered ?1, ?2, … placeholders.



DollarNumber

Numbered $1, $2, … placeholders.