pub enum Resolved<'a> {
Field(&'a Field),
Variant(&'a EnumVariant),
}Expand description
Result of resolving a projection through the application schema.
A projection can resolve to either a concrete field or an enum variant (when the projection stops at a variant discriminant without descending into a variant’s fields).
Variants
Field(&'a Field)
The projection resolved to a concrete field.
Variant(&'a EnumVariant)
The projection resolved to an enum variant (discriminant-only access).