pub enum SerializeFormat {
Json,
}Expand description
The serialization format used to store a field value in the database.
When a field’s in-memory type does not map directly to a database column type, the value is serialized into a format the database can store (e.g., a JSON string column).
Examples
use toasty_core::schema::app::SerializeFormat;
let fmt = SerializeFormat::Json;Variants
Json
Serialize the value as JSON using serde_json.