EmbeddedStruct

Struct EmbeddedStruct 

pub struct EmbeddedStruct {
    pub id: ModelId,
    pub name: Name,
    pub fields: Vec<Field>,
    pub indices: Vec<Index>,
}
An embedded struct model whose fields are flattened into its parent model’s database table.

Embedded structs do not have their own table or primary key. Their fields become additional columns in the parent table. Indices declared on an embedded struct’s fields are propagated to physical DB indices on the parent table.

Examples

let embedded = model.as_embedded_struct_unwrap();
for field in &embedded.fields {
    println!("  embedded field: {}", field.name);
}

Fields

id: ModelId

Uniquely identifies this model within the schema.

name: Name

The model’s name.

fields: Vec<Field>

Fields contained by this embedded struct.

indices: Vec<Index>

Indices defined on this embedded struct’s fields.

These reference fields within this embedded struct (not the parent model). The schema builder propagates them to physical DB indices on the parent table’s flattened columns.