pub struct ForeignKeyField {
pub source: FieldId,
pub target: FieldId,
}Expand description
One column-pair within a ForeignKey.
Maps a single field on the source (owning) model to the corresponding field on the target (referenced) model.
Examples
use toasty_core::schema::app::{ForeignKeyField, ModelId};
let fkf = ForeignKeyField {
source: ModelId(0).field(2),
target: ModelId(1).field(0),
};Fields
source: FieldIdThe field on the source model that stores the foreign key value.
target: FieldIdThe field on the target model that this foreign key references.
Implementations