pub struct IndexField {
pub field: FieldId,
pub op: IndexOp,
pub scope: IndexScope,
}Expand description
A single field entry within an Index.
Describes which field is indexed, the comparison operation used for lookups, and whether this field is a partition key or a local (sort) key.
Examples
use toasty_core::schema::app::{IndexField, ModelId};
use toasty_core::schema::db::{IndexOp, IndexScope};
let field = IndexField {
field: ModelId(0).field(1),
op: IndexOp::Eq,
scope: IndexScope::Local,
};Fields
field: FieldIdThe field being indexed.
op: IndexOpThe comparison operation used when querying this index field.
scope: IndexScopeWhether this field is a partition key or a local (sort) key.