pub struct ModelSet { /* private fields */ }Expand description
An ordered collection of Model definitions.
ModelSet is the primary container used to hold all models in a schema.
Models are stored in insertion order and can be iterated over by reference
or by value.
Examples
use toasty_core::schema::app::{Model, ModelSet};
let set = ModelSet::new();
assert_eq!((&set).into_iter().len(), 0);Implementations