pub struct PrimaryKey {
pub fields: Vec<FieldId>,
pub index: IndexId,
}Expand description
The primary key definition for a root model.
A primary key consists of one or more fields that uniquely identify a
record, plus a reference to the backing Index.
Examples
use toasty_core::schema::app::{PrimaryKey, IndexId, ModelId};
let pk = PrimaryKey {
fields: vec![ModelId(0).field(0)],
index: IndexId { model: ModelId(0), index: 0 },
};
assert_eq!(pk.fields.len(), 1);Fields
fields: Vec<FieldId>The fields that compose this primary key, in order.
index: IndexIdThe IndexId of the index backing this primary key.