pub enum IndexScope {
Partition,
Local,
}Variants
Partition
The index column is used to partition rows across nodes of a distributed database.
Local
The index column is scoped to a physical node.
Implementations
Sourceimpl IndexScope
impl IndexScope