pub struct Column {
pub id: ColumnId,
pub name: String,
pub ty: Type,
pub storage_ty: Type,
pub nullable: bool,
pub primary_key: bool,
pub auto_increment: bool,
}Fields
id: ColumnIdUniquely identifies the column in the schema.
name: StringThe name of the column in the database.
ty: TypeThe column type, from Toasty’s point of view.
storage_ty: TypeThe database storage type of the column.
nullable: boolWhether or not the column is nullable
primary_key: boolTrue if the column is part of the table’s primary key
auto_increment: boolTrue if the column is an integer that should be auto-incremented
with each insertion of a new row. This should be false if a storage_ty
of type Serial is used.