pub struct Schema {
pub tables: Vec<Table>,
}Expand description
Fields
tables: Vec<Table>All tables in this schema.
Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn column_mut(&mut self, id: impl Into<ColumnId>) -> &mut Column
pub fn column_mut(&mut self, id: impl Into<ColumnId>) -> &mut Column
Returns a mutable reference to the column identified by id.
Panics
Panics if the table or column index is out of bounds.
Sourcepub fn index_mut(&mut self, id: IndexId) -> &mut Index
pub fn index_mut(&mut self, id: IndexId) -> &mut Index
Returns a mutable reference to the index identified by id.
Panics
Panics if the table or index offset is out of bounds.