Schema

Struct Schema 

pub struct Schema<'a> { /* private fields */ }
The top-level diff between two database schemas.

Contains a [Tables] describing created, dropped, and altered tables. Constructed via Schema::from.

Examples

use toasty_core::schema::{db, diff};

let previous = db::Schema::default();
let next = db::Schema::default();
let hints = diff::RenameHints::new();
let d = diff::Schema::from(&previous, &next, &hints);
assert!(d.is_empty());

Implementations

Source

impl<'a> Schema<'a>

pub fn from( from: &'a Schema, to: &'a Schema, rename_hints: &'a RenameHints, ) -> Self

Computes the diff between two schemas, using the provided rename hints.

pub fn types(&self) -> Vec<Type<'a>>

Computes the enum type diff between the two schemas.

pub fn tables(&self) -> &[Table<'a>]

Returns the table-level diff.

pub fn is_empty(&self) -> bool

Returns true if no tables were created, dropped, or altered.

pub fn previous(&self) -> &'a Schema

Returns the schema before the change.

pub fn next(&self) -> &'a Schema

Returns the schema after the change.