FieldRelation

Struct FieldRelation 

pub struct FieldRelation {
    pub field_mask: PathFieldSet,
}
Maps a relation field (BelongsTo, HasMany, HasOne).

Relations don’t map to columns in this table — they are resolved through joins or foreign keys in other tables. A unique bit is assigned in the model’s field mask space so that relation assignments are detected uniformly through the same mask intersection logic used for primitive and embedded fields.

Fields

field_mask: PathFieldSet

Update coverage mask for this relation field.