BinaryOp

Enum BinaryOp 

pub enum BinaryOp {
    Eq,
    Ne,
    Ge,
    Gt,
    Le,
    Lt,
}

Variants



Eq



Ne



Ge



Gt



Le



Lt

Implementations

Source

impl BinaryOp

pub fn is_eq(self) -> bool

pub fn is_ne(self) -> bool

pub fn reverse(&mut self)

pub fn negate(self) -> Option<Self>

Returns the logical negation of this operator, if one exists.

  • =!=
  • !==
  • <>=
  • >=<
  • ><=
  • <=>
pub fn commute(self) -> Self

Returns the operator that represents an equivalent comparison when the operands are commuted (swapped).

For example, 5 < x becomes x > 5, so Lt.commute() returns Gt. Symmetric operators like Eq and Ne return themselves.