pub struct ExprAny {
pub expr: Box<Expr>,
}Expand description
Returns true if any item in a collection evaluates to true.
Evaluates its inner expression and returns true if at least one item is
truthy. Returns false for an empty collection.
Examples
any([true, false, false]) // returns `true`
any([false, false]) // returns `false`
any([]) // returns `false`Fields
expr: Box<Expr>Expression that evaluates to a list.