pub struct ExprInSubquery {
pub expr: Box<Expr>,
pub query: Box<Query>,
}Expand description
Tests whether a value is in the results of a subquery.
Returns true if expr matches any row returned by query.
Examples
in_subquery(x, select(...)) // returns `true` if `x` is in the subquery resultsFields
expr: Box<Expr>The value to search for.
query: Box<Query>The subquery to search within.