pub fn visit_expr_default<V>(v: &mut V)Expand description
Default traversal for Expr::Default nodes. This is a leaf node with no children to visit.
pub fn visit_expr_default<V>(v: &mut V)Default traversal for Expr::Default nodes. This is a leaf node with no children to visit.