pub fn visit_source_table_id<V>(v: &mut V, node: &SourceTableId)Expand description
Default traversal for SourceTableId nodes. This is a leaf node with no children to visit.
pub fn visit_source_table_id<V>(v: &mut V, node: &SourceTableId)Default traversal for SourceTableId nodes. This is a leaf node with no children to visit.