pub struct QueryPk {
pub table: TableId,
pub index: Option<IndexId>,
pub select: Vec<ColumnId>,
pub pk_filter: Expr,
pub filter: Option<Expr>,
pub limit: Option<i64>,
pub order: Option<Direction>,
pub cursor: Option<Value>,
}Fields
table: TableIdTable to query
index: Option<IndexId>Optional index to query. None = primary key, Some(id) = secondary index
select: Vec<ColumnId>Which columns to get
pk_filter: ExprHow to filter the index.
filter: Option<Expr>Additional filtering done on the result before returning it to the caller.
limit: Option<i64>Maximum number of items to return. None means no limit.
order: Option<Direction>Sort key ordering direction for queries on a table with a composite
primary key. None uses the driver’s default ordering.
cursor: Option<Value>Cursor for resuming a paginated query. Contains the serialized key of the last item from a previous page of results.