pub struct QuerySql {
pub stmt: Statement,
pub ret: Option<Vec<Type>>,
pub last_insert_id_hack: Option<u64>,
}Fields
stmt: StatementThe SQL query to execute
ret: Option<Vec<Type>>The return type
last_insert_id_hack: Option<u64>TEMPORARY HACK: MySQL-specific workaround for RETURNING from INSERT.
When set, indicates this query should be preceded by fetching LAST_INSERT_ID() to simulate RETURNING behavior for the specified number of inserted rows. The query will return a list of rows, each with a single column containing the auto-increment ID.
Non-MySQL drivers should assert this is None.