pub struct UpdateByKey {
pub table: TableId,
pub keys: Vec<Value>,
pub assignments: Assignments,
pub filter: Option<Expr>,
pub condition: Option<Expr>,
pub returning: bool,
}Fields
table: TableIdWhich table to update
keys: Vec<Value>Which keys to update
assignments: AssignmentsHow to update the table
filter: Option<Expr>Only update keys that match the filter
condition: Option<Expr>Any conditions that must hold to apply the update
returning: boolIf true, then the driver should return a record for each instance of the model that was updated.