SchemaMutations

Struct SchemaMutations 

pub struct SchemaMutations {
    pub alter_column_type: bool,
    pub alter_column_properties_atomic: bool,
}
The database’s capabilities to mutate the schema (tables, columns, indices).

Used by the migration generator to decide how to express schema changes. For example, SQLite cannot alter column types so migrations must recreate the table instead.

Pre-built configurations: SQLITE, POSTGRESQL, MYSQL, DYNAMODB.

Examples

Access through Capability::schema_mutations:

use toasty_core::driver::Capability;

let cap = &Capability::POSTGRESQL;
assert!(cap.schema_mutations.alter_column_type);
assert!(!cap.schema_mutations.alter_column_properties_atomic);

Fields

alter_column_type: bool

Whether the database can change the type of an existing column.

alter_column_properties_atomic: bool

Whether the database can change name, type and constraints of a column all withing a single statement.

Implementations

Source

impl SchemaMutations

pub const SQLITE: Self

SQLite schema mutation capabilities. SQLite cannot alter column types.

pub const POSTGRESQL: Self

PostgreSQL schema mutation capabilities. Supports altering column types but not atomically changing multiple column properties.

pub const MYSQL: Self

MySQL schema mutation capabilities. Supports altering column types and atomically changing multiple column properties in a single statement.

pub const DYNAMODB: Self

DynamoDB schema mutation capabilities. Migrations are not currently supported.