pub struct BelongsTo {
pub target: ModelId,
pub expr_ty: Type,
pub pair: Option<FieldId>,
pub foreign_key: ForeignKey,
}Fields
target: ModelIdModel that owns the relation
expr_ty: TypeThe association’s expression type. This is the type the field evaluates to from a user’s point of view.
pair: Option<FieldId>The HasMany or HasOne association that pairs with this
foreign_key: ForeignKeyThe foreign key is a set of primitive fields that match the target’s primary key.
Implementations