Field

Struct Field 

pub struct Field {
    pub id: FieldId,
    pub name: FieldName,
    pub ty: FieldTy,
    pub nullable: bool,
    pub primary_key: bool,
    pub auto: Option<AutoStrategy>,
    pub constraints: Vec<Constraint>,
    pub variant: Option<VariantId>,
}

Fields

id: FieldId

Uniquely identifies the field within the containing model.

name: FieldName

The field name

ty: FieldTy

Primitive, relation, composite, …

nullable: bool

True if the field can be nullable (None in Rust).

primary_key: bool

True if the field is part of the primary key

auto: Option<AutoStrategy>

Specified if and how Toasty should automatically populate this field for new values

constraints: Vec<Constraint>

Any additional field constraints

variant: Option<VariantId>

If this field belongs to an enum variant, identifies that variant. None for fields on root models and embedded structs.

Implementations

Source

impl Field

pub fn id(&self) -> FieldId

Gets the id.

pub fn name(&self) -> &FieldName

Gets the name.

pub fn ty(&self) -> &FieldTy

Gets the type.

pub fn nullable(&self) -> bool

Gets whether the field is nullable.

pub fn primary_key(&self) -> bool

Gets the primary key.

pub fn auto(&self) -> Option<&AutoStrategy>

Gets the [Auto].

pub fn is_auto_increment(&self) -> bool

pub fn is_relation(&self) -> bool

pub fn full_name(&self, schema: &Schema) -> String

Returns a fully qualified name for the field.

pub fn relation_target_id(&self) -> Option<ModelId>

If the field is a relation, return the relation’s target ModelId.

pub fn relation_target<'a>(&self, schema: &'a Schema) -> Option<&'a Model>

If the field is a relation, return the target of the relation.

pub fn expr_ty(&self) -> &Type

The type the field evaluates too. This is the “expression type”.

pub fn pair(&self) -> Option<FieldId>