pub struct FieldPrimitive {
pub ty: Type,
pub storage_ty: Option<Type>,
pub serialize: Option<SerializeFormat>,
}Fields
ty: TypeThe field’s primitive type
storage_ty: Option<Type>The database storage type of the field.
This is specified as a hint.
serialize: Option<SerializeFormat>If set, the field value is serialized using the specified format before being stored in the database.