pub struct ForeignKeyField {
pub source: FieldId,
pub target: FieldId,
}Fields
source: FieldIdThe field on the source model that is acting as the foreign key
target: FieldIdThe field on the target model that this FK field maps to.
Implementations