Schema

Struct Schema 

pub struct Schema<'a> { /* private fields */ }
The top-level diff between two database schemas.

Contains a Tables describing created, dropped, and altered tables. Constructed via Schema::from.

Examples

use toasty_core::schema::{db::Schema as DbSchema, diff};

let previous = DbSchema::default();
let next = DbSchema::default();
let hints = diff::RenameHints::new();
let d = diff::Schema::from(&previous, &next, &hints);
assert!(d.is_empty());

Implementations

Source

impl<'a> Schema<'a>

pub fn from( from: &'a DbSchema, to: &'a DbSchema, rename_hints: &'a RenameHints, ) -> Self

Computes the diff between two schemas, using the provided rename hints.

pub fn types(&self) -> Types<'a>

Computes the enum type diff between the two schemas.

pub fn tables(&self) -> &Tables<'a>

Returns the table-level diff.

pub fn is_empty(&self) -> bool

Returns true if no tables were created, dropped, or altered.

pub fn previous(&self) -> &'a DbSchema

Returns the schema before the change.

pub fn next(&self) -> &'a DbSchema

Returns the schema after the change.