Statement

Enum Statement 

pub enum Statement {
    Delete(Delete),
    Insert(Insert),
    Query(Query),
    Update(Update),
}

Variants



Delete(Delete)

Delete one or more existing records



Insert(Insert)

Create one or more instances of a model



Query(Query)

Query the database



Update(Update)

Update one or more existing records

Implementations

Source

impl Statement

Source

impl Statement

pub fn condition(&self) -> Option<&Condition>

pub fn condition_mut(&mut self) -> Option<&mut Condition>

Returns a mutable reference to the statement’s condition.

Returns None for statements that do not support conditions.

pub fn condition_mut_unwrap(&mut self) -> &mut Condition

Returns a mutable reference to the statement’s condition.

Panics

Panics if the statement does not support conditions.

Source

impl Statement

pub fn is_delete(&self) -> bool

pub fn as_delete(&self) -> Option<&Delete>

Attempts to return a reference to an inner Delete.

pub fn into_delete(self) -> Option<Delete>

Consumes self and attempts to return the inner Delete.

pub fn unwrap_delete(self) -> Delete

Consumes self and returns the inner Delete.

Panics

If self is not a Statement::Delete.

Source

impl Statement

pub fn eval(&self, input: impl Input) -> Result<Value>

pub fn eval_const(&self) -> Result<Value>

Source

impl Statement

pub fn filter(&self) -> Option<&Filter>

pub fn filter_unwrap(&self) -> &Filter

pub fn filter_or_default(&self) -> &Filter

pub fn filter_mut(&mut self) -> Option<&mut Filter>

Returns a mutable reference to the statement’s filter.

Returns None for statements that do not support filtering, such as INSERT.

pub fn filter_mut_unwrap(&mut self) -> &mut Filter

Returns a mutable reference to the statement’s filter.

Panics

Panics if the statement does not support filtering.

pub fn filter_expr_unwrap(&self) -> &Expr

pub fn filter_expr_mut(&mut self) -> Option<&mut Expr>

Source

impl Statement

pub fn is_insert(&self) -> bool

pub fn as_insert(&self) -> Option<&Insert>

Attempts to return a reference to an inner Insert.

pub fn into_insert(self) -> Option<Insert>

Consumes self and attempts to return the inner Insert.

pub fn unwrap_insert(self) -> Insert

Consumes self and returns the inner Insert.

Panics

If self is not a Statement::Insert.

Source

impl Statement

pub fn is_query(&self) -> bool

pub fn as_query(&self) -> Option<&Query>

Attempts to return a reference to an inner Query.

pub fn as_query_mut(&mut self) -> Option<&mut Query>

Returns a mutable reference to the inner Query, if this is a query statement.

pub fn into_query(self) -> Query

Consumes self and returns the inner Query.

Panics

If self is not a Statement::Query.

Source

impl Statement

pub fn returning(&self) -> Option<&Returning>

Returns a reference to this statement’s RETURNING clause, if present.

Returns None if the statement does not have a RETURNING clause or is a statement type that does not support RETURNING.

pub fn take_returning(&mut self) -> Option<Returning>

Take the Returning clause

pub fn set_returning(&mut self, returning: Returning)

Set the Returning clause

pub fn returning_unwrap(&self) -> &Returning

Returns a reference to this statement’s RETURNING clause.

Panics

Panics if the statement does not have a RETURNING clause.

pub fn returning_mut(&mut self) -> Option<&mut Returning>

Returns a mutable reference to this statement’s RETURNING clause, if present.

Returns None if the statement does not have a RETURNING clause or is a statement type that does not support RETURNING.

pub fn returning_mut_unwrap(&mut self) -> &mut Returning

Returns a mutable reference to this statement’s RETURNING clause.

Panics

Panics if the statement does not have a RETURNING clause. This can occur when:

  • A DELETE, INSERT, or UPDATE statement was created without specifying a RETURNING clause (the internal Option<Returning> is None)
  • A Query statement contains a non-SELECT body (e.g., VALUES, UNION)
Examples
let mut stmt = Statement::Insert(insert_with_returning);
let returning = stmt.returning_mut_unwrap();
// Modify the returning clause...
Notes

This method uses #[track_caller] to report the panic location at the call site rather than inside this method, making debugging easier.

Source

impl Statement

pub fn as_select(&self) -> Option<&Select>

pub fn as_select_unwrap(&self) -> &Select

Source

impl Statement

pub fn is_update(&self) -> bool

Source

impl Statement

pub fn substitute(&mut self, input: impl Input)

pub fn is_const(&self) -> bool

pub fn as_update(&self) -> Option<&Update>

Attempts to return a reference to an inner Update.

pub fn into_update(self) -> Option<Update>

Consumes self and attempts to return the inner Update.

pub fn unwrap_update(self) -> Update

Consumes self and returns the inner Update.

Panics

If self is not a Statement::Update.