pub struct ExprArg {
pub position: usize,
pub nesting: usize,
}Expand description
A positional argument placeholder.
Represents a reference to an input value by position. During substitution,
arg(n) is replaced with the nth value from the input.
Examples
arg(0) // refers to the first input value
arg(1) // refers to the second input valueFields
position: usizeThe zero-based position of the argument.
nesting: usizeWhich “argument scope” this references. This is the number of scopes up from the current scope. Scopes are created by functional expressions like Expr::Map.
Implementations